## Overview

**IMPORTANT NOTE ON EMBARGO AND METHODOLOGY HERE**

**Webinar materials**

* Slides:

* Recording:

1-4 paragraphs abstracting the wire story, our findings, the stakes, and methodology

## Findings

* Summary item 1

* Summary item 2

* Summary item 3

## About This Data

Notes on what data source was used and what transformations were done.

## Included Data

_filename_ - A description of the file contents

## Additional Data Queries

* High level description of a task (ex. view national aggregates)

    * _Name of query_

## Using This Data

Notes and suggestions for reporters on using this data for their own stories

## Caveats

* Caveat item 1

* Caveat item 2


###### Contact reporters X at <X@ap.org> or Y at <Y@ap.org>.